@@ -58,7 +58,7 @@ class CrashReport:
     Report crash to a third party service
     """
 
-    DSN = "https://d4a76fe0441b47c28b19b66ce6d1c7c0:129a91b7ae0e4ec6acba1cccb61b97f3@o19455.ingest.sentry.io/38482"
+    DSN = "https://464a18a662fa482bad15b5ea0c899d5d:cef46213853149e7b6633019302e6bfd@o19455.ingest.sentry.io/38482"
     _instance = None
 
     def __init__(self):
@@ -133,7 +133,7 @@ class CrashReport:
                 for key, value in extra_context.items():
                     scope.set_extra(key, value)
 
-    def capture_exception(self, request):
+    def capture_exception(self, request=None):
 
         if not SENTRY_SDK_AVAILABLE:
             return
